var searchData=
[
  ['changedatatype',['changeDatatype',['../class_r_nifti_1_1_nifti_image.html#a284ee3a4560ff5371aa915a9c98c8146',1,'RNifti::NiftiImage::changeDatatype(const short datatype, const bool useSlope=false)'],['../class_r_nifti_1_1_nifti_image.html#aa1da7aa44bbe4d60974be6ebb94a95e2',1,'RNifti::NiftiImage::changeDatatype(const std::string &amp;datatype, const bool useSlope=false)']]],
  ['copy',['copy',['../class_r_nifti_1_1_nifti_image.html#aeb1d5e30e3d28a07b69844cec2514144',1,'RNifti::NiftiImage::copy(const nifti_image *source)'],['../class_r_nifti_1_1_nifti_image.html#aab05a75827764608bbcb67251a5e8eba',1,'RNifti::NiftiImage::copy(const NiftiImage &amp;source)'],['../class_r_nifti_1_1_nifti_image.html#ad0fb9f9754e9c0e3692b9fbf5821705a',1,'RNifti::NiftiImage::copy(const Block &amp;source)']]]
];
